<?php
/**
 * The admin specific functionality of the plugin.
 *
 * @author  : Ginger Plugins <gingerplugins@gmail.com>
 * @license : GPL2
 * */

defined('ABSPATH') or die('Direct Access is not allowed');

class GP_Admin_Common_Sticky_Chat_Widget
{

    /**
     * The slug of this plugin.
     *
     * @var    string    $slug    The slug of this plugin.
     * @since  1.1.2
     * @access public
     */
    public $slug = "sticky-chat-widget";

    /**
     * The name of this plugin.
     *
     * @var    string    $pluginName    The name of this plugin.
     * @since  1.1.2
     * @access public
     */
    public $pluginName = "Sticky Chat Widget";

    /**
     * The affiliate link of this plugin.
     *
     * @var    string    $affiliateLink    The affiliate link of this plugin.
     * @since  1.1.2
     * @access public
     */
    public $affiliateLink;

    /**
     *  The response of submit a form.
     *
     * @var    array    $response    The response of submit a form.
     * @since  1.1.2
     * @access public
     */
    public $response;

    /**
     *  The email of this plugin.
     *
     * @var    array    $email    The email of this plugin.
     * @since  1.1.2
     * @access protected
     */
    protected $email = "contact@gingerplugins.com";


    /**
     * Initialize the class and set its properties.
     *
     * @since 1.1.2
     */
    public function __construct()
    {
        add_action('admin_enqueue_scripts', [ $this, 'admin_script' ]);

        // Creating menu in admin for Ginger social chat button settings.
        add_action('admin_menu', [$this, 'admin_menu'], 100);

        // Deactivate Plugin.
        add_action("wp_ajax_".$this->slug."-plugin_deactivate_form", [ $this, 'plugin_deactivate_form_request']);

        // Contact Form.
        add_action("wp_ajax_".$this->slug."_contact_ginger_form", [ $this, 'contact_ginger']);

        // Contact Form.
        add_action("wp_ajax_".$this->slug."_update_review_box_status", [ $this, 'update_review_box_status']);

        // Rating message.
        add_action('in_admin_header', [$this, 'in_admin_header']);

        // Deactivate form.
        add_action('admin_footer', [$this, 'plugin_deactivate_form']);

        $this->affiliateLink = "https://www.gingerplugins.com/affiliate-area/?plugin=".$this->slug."&domain=".$_SERVER['HTTP_HOST'];

        // Default AJAX response array.
        $this->response = [
            'status'  => 0,
            'data'    => 0,
            'errors'  => [],
            'message' => "",
        ];

    }//end __construct()


    /**
     * Update review box status for show a review notice.
     *
     * @since  1.1.2
     * @return null
     */
    public function update_review_box_status()
    {
        $errorMessage = esc_html__("%s is required", 'sticky-chat-widget');
        $post         = filter_input_array(INPUT_POST);
        $errors       = [];

        if (isset($post['nonce']) && !empty($post['nonce'])) {
            if (wp_verify_nonce($post['nonce'], $this->slug."-review-box-status")) {
                $noOfDays = isset($post['day_interval']) ? $post['day_interval'] : 7;
                if ($noOfDays == -1) {
                    update_option($this->slug."_review_box_status", 1);
                } else {
                    $noOfDays = 7;
                    $nextDate = date("Y-m-d", strtotime("+".$noOfDays." days"));
                    update_option($this->slug."_review_date", $nextDate);
                }
            }
        }

    }//end update_review_box_status()


    /**
     * Show review notice.
     *
     * @since  1.1.2
     * @return null
     */
    public function in_admin_header()
    {
        if(isset($_GET['page']) && ($_GET['page'] == "sticky-chat-widget" || $_GET['page'] == "sticky-chat-widget-upgrade-to-pro")) {
            remove_all_actions('admin_notices');
            remove_all_actions('all_admin_notices');

            add_action('admin_notices', [$this, 'admin_notices']);
        }
    }


    /**
     * Show review notice.
     *
     * @since  1.1.2
     * @return null
     */
    public function admin_notices()
    {
        if(isset($_GET['page']) && ($_GET['page'] == "sticky-chat-widget" || $_GET['page'] == "sticky-chat-widget-upgrade-to-pro")) {
            remove_all_actions('admin_notices');
            remove_all_actions('all_admin_notices');
        }

        $isHidden = get_option($this->slug."_review_box_status");
        if ($isHidden !== false) {
            return;
        }

        $reviewDate = get_option($this->slug."_review_date");
        if ($reviewDate === false) {
            $date = date("Y-m-d", strtotime("+7 days"));
            add_option($this->slug."_review_date", $date);
            return;
        }

        $currentDate = date("Y-m-d");
        if ($currentDate < $reviewDate) {
            return;
        }

        include_once dirname(__FILE__)."/templates/admin-notice.php";

    }//end admin_notices()


    /**
     * Send mail when deactivate a plugin.
     *
     * @since  1.1.2
     * @return null
     */
    public function plugin_deactivate_form_request()
    {
        $errorMessage = esc_html__("%s is required", 'sticky-chat-widget');
        $post         = filter_input_array(INPUT_POST);
        $errors       = [];

        $emailId = "no-reply@domain.com";

        if (!isset($post['deactivate_email']) || empty($post['deactivate_email'])) {
            $errors[] = [
                'key'     => 'deactivate_email',
                'message' => sprintf($errorMessage, esc_html__("Email", 'sticky-chat-widget')),
            ];
        } else if (!filter_var($post['deactivate_email'], FILTER_VALIDATE_EMAIL)) {
            $errors[] = [
                'key'     => 'deactivate_email',
                'message' => esc_html__('Email address is not valid', 'sticky-chat-widget'),
            ];
        } else {
            $emailId = $post['deactivate_email'];
        }

        if (!isset($post['deactivate_comment']) || empty($post['deactivate_comment'])) {
            $errors[] = [
                'key'     => 'deactivate_comment',
                'message' => sprintf($errorMessage, esc_html__("Message", 'sticky-chat-widget')),
            ];
        }

        if (empty($errors)) {
            if (!isset($post['deactivate_nonce']) || empty($post['deactivate_nonce'])) {
                $this->response['message'] = esc_html__("Your request is not valid", 'sticky-chat-widget');
            } else if (!wp_verify_nonce($post['deactivate_nonce'], $this->slug."-deactivate-plugin")) {
                $this->response['message'] = esc_html__("Your request is not valid", 'sticky-chat-widget');
            } else {
                global $current_user;
                $name = "Unknown Person";
                if (isset($current_user->first_name) && isset($current_user->first_name)) {
                    $name = trim($current_user->first_name." ".$current_user->last_name);
                }

                ob_start();
                ?>
                <table cellspacing="0" border="0">
                    <tr>
                        <th align="left">Name</th>
                        <td><?php echo esc_attr($name) ?></td>
                    </tr>
                    <tr>
                        <th align="left">Email</th>
                        <td><?php echo esc_attr($emailId) ?></td>
                    </tr>
                    <tr>
                        <th align="left">Message</th>
                        <td><?php echo nl2br(esc_attr($post['deactivate_comment'])) ?></td>
                    </tr>
                    <tr>
                        <th align="left">Plugin</th>
                        <td><?php echo esc_attr($this->pluginName) ?></td>
                    </tr>
                    <tr>
                        <th align="left">Plugin Version</th>
                        <td><?php echo esc_attr(GSB_PLUGIN_VERSION) ?></td>
                    </tr>
                    <tr>
                        <th align="left">Domain</th>
                        <td><?php echo esc_url(site_url()) ?></td>
                    </tr>
                    <tr>
                        <th align="left">WordPress Version</th>
                        <td><?php echo esc_attr(get_bloginfo('version')) ?></td>
                    </tr>
                    <tr>
                        <th align="left">PHP Version</th>
                        <td><?php echo esc_attr(PHP_VERSION) ?></td>
                    </tr>
                </table>
                <?php
                $message = ob_get_clean();

                $headers  = "MIME-Version: 1.0\r\n";
                $headers .= "Content-Type: text/html; charset=UTF-8\r\n";
                $headers .= 'From:'.$name.' <'.$emailId.'>'.PHP_EOL;
                $headers .= 'Reply-To:'.$name.'<'.$emailId.'>'.PHP_EOL;
                $headers .= 'X-Mailer: PHP/'.phpversion();

                $subject = $this->pluginName." was removed from ".site_url();

                // Sending an Email.
                wp_mail($this->email, $subject, $message, $headers);
                $this->response['status']  = 1;
                $this->response['message'] = esc_html__("Your message has been sent successfully", 'sticky-chat-widget');
            }//end if
        }//end if

        echo json_encode($this->response);
        exit;

    }//end plugin_deactivate_form_request()


    /**
     * Display a form when user deactivate a plugin.
     *
     * @since  1.1.2
     * @return null
     */
    public function plugin_deactivate_form()
    {
        global $pagenow;
        if ($pagenow !== 'plugins.php') {
            return;
        }

        include_once dirname(__FILE__)."/templates/plugin-deactivate.php";

    }//end plugin_deactivate_form()


    /**
     * Send mail to ginger plugin when submit a help form.
     *
     * @since  1.1.2
     * @return null
     */
    public function contact_ginger()
    {
        $errorMessage = esc_html__("%s is required", 'sticky-chat-widget');
        $post         = filter_input_array(INPUT_POST);
        $errors       = [];
        if (!isset($post['name']) || empty($post['name'])) {
            $errors[] = [
                'key'     => 'name',
                'message' => sprintf($errorMessage, esc_html__("Name", 'sticky-chat-widget')),
            ];
        }

        if (!isset($post['email']) || empty($post['email'])) {
            $errors[] = [
                'key'     => 'email',
                'message' => sprintf($errorMessage, esc_html__("Email", 'sticky-chat-widget')),
            ];
        } else if (!filter_var($post['email'], FILTER_VALIDATE_EMAIL)) {
            $errors[] = [
                'key'     => 'email',
                'message' => esc_html__('Email address is not valid', 'sticky-chat-widget'),
            ];
        }

        if (!isset($post['message']) || empty($post['message'])) {
            $errors[] = [
                'key'     => 'message',
                'message' => sprintf($errorMessage, esc_html__("Message", 'sticky-chat-widget')),
            ];
        }

        if (empty($errors)) {
            if (!isset($post['nonce']) || empty($post['nonce'])) {
                $this->response['message'] = esc_html__("Your request is not valid", 'sticky-chat-widget');
            } else if (!wp_verify_nonce($post['nonce'], $this->slug."ajax-contact-form")) {
                $this->response['message'] = esc_html__("Your request is not valid", 'sticky-chat-widget');
            } else {
                ob_start(); ?>
                    <table cellspacing="0" border="0">
                        <tr>
                            <th align="left">Name</th>
                            <td><?php echo esc_attr($post['name']) ?></td>
                        </tr>
                        <tr>
                            <th align="left">Email</th>
                            <td><?php echo esc_attr($post['email']) ?></td>
                        </tr>
                        <tr>
                            <th align="left">Message</th>
                            <td><?php echo esc_attr($post['message']) ?></td>
                        </tr>
                        <tr>
                            <th align="left">Plugin</th>
                            <td><?php echo esc_attr($this->pluginName) ?></td>
                        </tr>
                        <tr>
                            <th align="left">Plugin Version</th>
                            <td><?php echo esc_attr(GSB_PLUGIN_VERSION) ?></td>
                        </tr>
                        <tr>
                            <th align="left">Domain</th>
                            <td><?php echo esc_url(site_url()) ?></td>
                        </tr>
                        <tr>
                            <th align="left">WordPress Version</th>
                            <td><?php echo esc_attr(get_bloginfo('version')) ?></td>
                        </tr>
                        <tr>
                            <th align="left">PHP Version</th>
                            <td><?php echo esc_attr(PHP_VERSION) ?></td>
                        </tr>
                    </table>
                <?php
                $message = ob_get_clean();

                $headers  = "MIME-Version: 1.0\r\n";
                $headers .= "Content-Type: text/html; charset=UTF-8\r\n";
                $headers .= 'From:'.$post['name'].' <'.$post['email'].'>'.PHP_EOL;
                $headers .= 'Reply-To:'.$post['name'].'<'.$post['email'].'>'.PHP_EOL;
                $headers .= 'X-Mailer: PHP/'.phpversion();

                $subject = "Message for ".$this->pluginName.": ".site_url();

                // Sending an Email.
                wp_mail($this->email, $subject, $message, $headers);
                $this->response['status']  = 1;
                $this->response['message'] = esc_html__("Your message has been sent successfully", 'sticky-chat-widget');
            }//end if
        } else {
            $this->response['errors'] = $errors;
        }//end if

        echo json_encode($this->response);
        exit;

    }//end contact_ginger()


    /**
     * Enqueue admin style and script file.
     *
     * @since  1.1.2
     * @param  string $hook The name of page in admin URL.
     * @return null
     */
    public function admin_script($hook)
    {
        if ($hook == "plugins.php") {
            wp_enqueue_script($this->slug.'-admin-deactivate-plugin', GSB_PLUGIN_URL."assets/admin/js/deactivate-plugin.js", ['jquery'], GSB_PLUGIN_VERSION);

            wp_enqueue_style($this->slug.'-admin-deactivate-plugin', GSB_PLUGIN_URL."assets/admin/css/deactivate-plugin.css", [], GSB_PLUGIN_VERSION);

            wp_localize_script(
                $this->slug.'-admin-deactivate-plugin',
                'SCW_SETTINGS',
                [
                    'ajax_url'         => admin_url('admin-ajax.php'),
                    'required_message' => esc_html__("Your comment is required", "sticky-chat-widget"),
                ]
            );
            return;
        }

        $pages = [
            'sticky-chat-widget_page_sticky-chat-widget-upgrade-to-pro',
            'toplevel_page_sticky-chat-widget',
        ];
        if (!in_array($hook, $pages)) {
            return;
        }

        $minified = ".min";
        if (GSB_DEV_VERSION) {
            $minified = "";
        }

        wp_enqueue_script($this->slug.'-admin-script', GSB_PLUGIN_URL."assets/admin/js/common-script".$minified.".js", ['jquery'], GSB_PLUGIN_VERSION);

        wp_enqueue_style($this->slug.'-admin-style', GSB_PLUGIN_URL."assets/admin/css/admin-style.min.css", [], GSB_PLUGIN_VERSION);

        wp_localize_script(
            $this->slug.'-admin-script',
            'GP_COMMON_SETTINGS',
            [
                'ajax_url'         => admin_url('admin-ajax.php'),
                'required_message' => esc_html__("%s is required", "sticky-chat-widget"),
            ]
        );

    }//end admin_script()


    /**
     * Add menu and submenu to this plugin in admin dashboard.
     *
     * @since  1.1.2
     * @return null
     */
    public function admin_menu()
    {
        add_submenu_page(
            $this->slug,
            __('Go Pro', 'sticky-chat-widget'),
            __('Go Pro', 'sticky-chat-widget'),
            'manage_options',
            $this->slug."-upgrade-to-pro",
            [
                $this,
                'admin_upgrade_to_pro',
            ]
        );

    }//end admin_menu()


    /**
     * Show a upgrade to pro page.
     *
     * @since  1.1.2
     * @return null
     */
    public function admin_upgrade_to_pro()
    {
        $cartUrl = "https://www.gingerplugins.com/checkout/?edd_action=add_to_cart&download_id=4104&edd_options[price_id]=";

        // Pro feature list.
        $priceFeatures = [
            [
                'tooltip' => esc_html__("Show different widgets for different pages based on page targeting rules. You can also show different channels on desktop and mobile", 'sticky-chat-widget'),
                'text'    => esc_html__("Multiple Widgets", 'sticky-chat-widget'),
            ],
            [
                'tooltip' => esc_html__("Upload custom icon, choose custom color for your widget button", 'sticky-chat-widget'),
                'text'    => esc_html__("Widget Customization", 'sticky-chat-widget'),
            ],
            [
                'tooltip' => esc_html__("Select from 22 chnnels also upload cutom icon", 'sticky-chat-widget'),
                'text'    => esc_html__("Channel Customization", 'sticky-chat-widget'),
            ],
            [
                'tooltip' => esc_html__("Select custom color for tooltip (on hover text)", 'sticky-chat-widget'),
                'text'    => esc_html__("Tooltip Customization", 'sticky-chat-widget'),
            ],
            [
                'tooltip' => esc_html__("Trigger widget button on page scroll, after some time interval or on exit intent", 'sticky-chat-widget'),
                'text'    => esc_html__("Triggers", 'sticky-chat-widget'),
            ],
            [
                'tooltip' => esc_html__("Select pages where you like to show or hide Sticky chat widget", 'sticky-chat-widget'),
                'text'    => esc_html__("Page Targeting", 'sticky-chat-widget'),
            ],
            [
                'tooltip' => esc_html__("Insert custom IDs and Class name to each chat channel", 'sticky-chat-widget'),
                'text'    => esc_html__("Custom IDs and Class", 'sticky-chat-widget'),
            ],
            [
                'tooltip' => esc_html__("Select week day and time when you like to show Sticky chat widget", 'sticky-chat-widget'),
                'text'    => esc_html__("Days and Time Selection", 'sticky-chat-widget'),
            ],
            [
                'tooltip' => esc_html__("Display sticky chat widget on custom location", 'sticky-chat-widget'),
                'text'    => esc_html__("Custom Location", 'sticky-chat-widget'),
            ],
            [
                'tooltip' => esc_html__("Track each channel's click on Google analytics", 'sticky-chat-widget'),
                'text'    => esc_html__("Google Analytics", 'sticky-chat-widget'),
            ],
        ];

        $faqs = [
            [
                "question" => esc_html__("Can I cancel my account at any time?", 'sticky-chat-widget'),
                "answer"   => esc_html__("Yes, if you ever decide that Sticky Chat Widget isn't the best plugin for you, simply cancel your account from your Account panel. You'll still be able to use the plugin without updates or support.", 'sticky-chat-widget'),
            ],
            [
                "question" => esc_html__("Can I change my plan later on?", 'sticky-chat-widget'),
                "answer"   => esc_html__("Absolutely! You can upgrade or downgrade your plan at any time.", 'sticky-chat-widget'),
            ],
            [
                "question" => esc_html__("What payment methods are accepted?", 'sticky-chat-widget'),
                "answer"   => esc_html__("We accept all major credit cards including Visa, Mastercard, American Express, as well as PayPal payments.", 'sticky-chat-widget'),
            ],
            [
                "question" => esc_html__("Do I get updates for the premium plugin?", 'sticky-chat-widget'),
                "answer"   => esc_html__("Yes! Automatic updates to our premium plugin are available free of charge as long as you stay our paying customer. If you cancel your subscription, you'll still be able to use our plugin without updates or support.", 'sticky-chat-widget'),
            ],
            [
                "question" => esc_html__("Do you offer support if I need help?", 'sticky-chat-widget'),
                "answer"   => esc_html__("Yes! Top-notch customer support for our paid as well as free customers. We'll do our very best to resolve any issues you encounter while using sticky chat widget.", 'sticky-chat-widget'),
            ],
        ];

        // Pro Price List.
        $prices = [
            "1_domain"   => [
                '1_year'   => [
                    'price' => "$25",
                    'id'    => 9,
                ],

                'lifetime' => [
                    'price' => "$79",
                    'id'    => 10,
                ],
            ],
            "5_domains"  => [
                '1_year'   => [
                    'price' => "$69",
                    'id'    => 11,
                ],

                'lifetime' => [
                    'price' => "$179",
                    'id'    => 12,
                ],
            ],
            "50_domains" => [
                '1_year'   => [
                    'price' => "$99",
                    'id'    => 13,
                ],

                'lifetime' => [
                    'price' => "$279",
                    'id'    => 14,
                ],
            ],
        ];

        $first = "Use sticky chat widget on ";

        include_once dirname(__FILE__)."/templates/upgrade-to-pro.php";

    }//end admin_upgrade_to_pro()


}//end class


$GP_admin_common_sticky_chat_widget = new GP_Admin_Common_Sticky_Chat_Widget();