<?php
/**
 * The admin specific functionality of the plugin.
 *
 * @author  : Ginger Plugins <gingerplugins@gmail.com>
 * @license : GPL2
 * */

defined('ABSPATH') or die('Direct Access is not allowed');

class GP_Admin_Sticky_Chat_Buttons
{

    /**
     * The slug of this plugin.
     *
     * @var    string    $slug    The slug of this plugin.
     * @since  1.1.2
     * @access public
     */
    public $slug = "sticky-chat-widget";


    /**
     * Initialize the class and set its properties.
     *
     * @since 1.1.2
     */
    public function __construct()
    {

        // CSS and JavaScript files for Ginger Sticky Chat Widget.
        add_action('admin_enqueue_scripts', [ $this, 'admin_script' ]);

        // Register a post type.
        add_action('init', [$this, 'register_post_type']);

        // Initialize settings.
        add_action('admin_init', [$this, 'migrate_data']);

        // Save settings.
        add_action('wp_ajax_save_gsb_buttons_setting', [$this, 'save_gsb_buttons_setting']);

        // Change a status of widget.
        add_action("wp_ajax_gsb_buttons_change_status", [$this, "gsb_buttons_change_status"]);

        // Remove a widget.
        add_action("wp_ajax_gsb_buttons_remove_widget", [$this, "gsb_buttons_remove_widget"]);

        // Creating menu in admin for Ginger Sticky Chat Widget settings.
        add_action('admin_menu', [$this, 'admin_menu']);

        // Get button data.
        add_action("wp_ajax_get_gb_settings", [$this, "get_gb_settings"]);

        // Add settings and upgrade link to plugin base.
        add_filter('plugin_action_links_'.GSB_PLUGIN_BASE, [$this, 'setting_and_upgrade_link']);

        // Plugin language files.
        add_action('plugins_loaded', [ $this, 'plugin_language' ]);

        // Sign up page.
        add_action('wp_ajax_scw_save_sign_up_info', [$this, "scw_save_sign_up_info"]);

        add_action('clear_cache_for_scw_plugin', [$this, "clear_cache_for_scw_plugin"]);

        add_action("upgrader_process_complete", [ $this, "migrate_data" ]);

        add_action("plugins_loaded", [ $this, "migrate_data" ]);

        add_action("wp_ajax_gsb_buttons_create_widget", [$this, "gsb_buttons_create_widget"]);

        add_action("wp_ajax_gsb_buttons_rename_widget", [$this, "gsb_buttons_rename_widget"]);

    }//end __construct()

    public function clear_cache_for_scw_plugin() {
        try {

            /* W3 Total Cache */
            global $wp_fastest_cache;
            if (function_exists('w3tc_flush_all')) {
                w3tc_flush_all();

            }

            /* WP Super Cache */
            if (function_exists('wp_cache_clean_cache')) {
                global $file_prefix, $supercachedir;
                if (empty($supercachedir) && function_exists('get_supercache_dir')) {
                    $supercachedir = get_supercache_dir();
                }
                wp_cache_clean_cache($file_prefix);
            }

            /* WP Fastest Cache Plugin */
            if (method_exists('WpFastestCache', 'deleteCache') && !empty($wp_fastest_cache)) {
                $wp_fastest_cache->deleteCache();
            }

            /* WP Rocket Plugin */
            if (function_exists('rocket_clean_domain')) {
                rocket_clean_domain();
                // Preload cache.
                if (function_exists('run_rocket_sitemap_preload')) {
                    run_rocket_sitemap_preload();
                }
            }

            /* Autoptimize Cache Plugin */
            if (class_exists("autoptimizeCache") && method_exists("autoptimizeCache", "clearall")) {
                autoptimizeCache::clearall();
            }

            /* LiteSpeed Plugin */
            if (class_exists("LiteSpeed_Cache_API") && method_exists("autoptimizeCache", "purge_all")) {
                LiteSpeed_Cache_API::purge_all();
            }

            /* Breeze Plugin */
            if (class_exists("Breeze_PurgeCache") && method_exists("Breeze_PurgeCache", "breeze_cache_flush")) {
                Breeze_PurgeCache::breeze_cache_flush();
            }

            /* Hummingbird */
            if (class_exists( '\Hummingbird\Core\Utils' ) ) {
                $modules   = \Hummingbird\Core\Utils::get_active_cache_modules();
                foreach ( $modules as $module => $name ) {
                    $mod = \Hummingbird\Core\Utils::get_module( $module );
                    if ( $mod->is_active() ) {
                        if ( 'minify' === $module ) {
                            $mod->clear_files();
                        } else {
                            $mod->clear_cache();
                        }
                    }
                }
            }

            /* WP Total Cache */
            if ( function_exists( 'wp_cache_clean_cache' ) ) {
                global $file_prefix;
                wp_cache_clean_cache( $file_prefix, true );
            }

            /* Site Optimizer */
            if(class_exists("Supercacher")) {
                if(method_exists("Supercacher", "delete_assets")) {
                    Supercacher::delete_assets();
                }
                if(method_exists("Supercacher", "purge_cache")) {
                    Supercacher::purge_cache();
                }
                if(method_exists("Supercacher", "flush_memcache")) {
                    Supercacher::flush_memcache();
                }
                if(method_exists("Supercacher", "purge_everything")) {
                    Supercacher::purge_everything();
                }
            }

            /* WP asset clean up plugin */
            if(class_exists("OptimizeCommon") && method_exists("OptimizeCommon", "clearCache")) {
                OptimizeCommon::clearCache();
            }

            // WP Rocket
            if ( function_exists( 'rocket_clean_domain' ) ) {
                rocket_clean_domain();
            }

            // WP Rocket: Clear minified CSS and JavaScript files.
            if ( function_exists( 'rocket_clean_minify' ) ) {
                rocket_clean_minify();
            }

        } catch (Exception $e) {
            return 1;
        }
    }


    /**
     * Define plugin language.
     *
     * @since  1.1.2
     * @return null.
     */
    public function plugin_language()
    {
        load_plugin_textdomain("sticky-chat-widget", false, dirname(plugin_basename(__FILE__)).'/languages/');

    }//end plugin_language()


    /**
     * Add setting and upgrade link.
     *
     * @since  1.1.2
     * @return array    The links of the plugin.
     */
    public function setting_and_upgrade_link($links)
    {
        $settings = '<a href="'.admin_url("admin.php?page=sticky-chat-widget").'" ><b>'.esc_attr('Settings', 'sticky-chat-widget').'</b></a>';
        array_unshift($links, $settings);
        $links['upgrade_link'] = '<a href="'.admin_url("admin.php?page=sticky-chat-widget-upgrade-to-pro").'" style="display: inline-block; color: #e91e63; font-weight: bold;" >'.esc_attr('Go Pro', 'sticky-chat-widget').'</a>';
        return $links;

    }//end setting_and_upgrade_link()


    /**
     * Get selected channels of widget.
     *
     * @since  1.1.2
     * @return array    The channel lists of the widget.
     */
    public static function get_selected_channels()
    {
        $channels = get_option("gsb_selected_channels");
        if ($channels == false) {
            return [
                "whatsapp",
                "facebook_messenger",
            ];
        }

        $channelArray = [];
        if (!empty($channels)) {
            $channels     = trim($channels);
            $channels     = trim($channels, ",");
            $channelArray = explode(",", $channels);
        }

        return $channelArray;

    }//end get_selected_channels()


    /**
     * Get channel setting.
     *
     * @since  1.1.2
     * @return null.
     */
    public function get_gb_settings()
    {
        $status = 0;

        $button = filter_input(INPUT_POST, 'button', FILTER_SANITIZE_STRING);
        $postId = filter_input(INPUT_POST, 'postId', FILTER_SANITIZE_STRING);

        $message = self::get_channel_settings($button, $postId);

        if (!empty($message)) {
            $status = 1;
        }

        $response = [
            'status'  => $status,
            'message' => $message,
        ];
        echo json_encode($response);
        wp_die();

    }//end get_gb_settings()


    /**
     * Get channel setting HTML design.
     *
     * @since  1.1.2
     * @param  string  $button The slug of channel.
     * @param  integer $postId The ID of widget.
     * @return string The html design of channel in json format.
     */
    public static function get_channel_settings($button, $postId)
    {
        $message     = "";
        $socialIcons = Ginger_Social_Icons::icon_list();
        $formIcons = Ginger_Social_Icons::svg_icons();

        $disabled = "disabled";

        foreach ($socialIcons as $key => $icon) {
            if ($key == $button) {
                ob_start();
                $defaultChannelSettings = [
                    'value'            => '',
                    'title'            => $icon['title'],
                    'for_desktop'      => 'yes',
                    'for_mobile'       => 'yes',
                    'image_id'         => '',
                    'bg_color'         => $icon['color'],
                    'text_color'       => '#ffffff',
                    'bg_hover_color'   => $icon['color'],
                    'text_hover_color' => '#ffffff',
                    'custom_id'        => '',
                    'custom_class'     => '',
                    'whatsapp_message' => '',
                    'email_subject'    => '',
                ];
                $allChannelSetting      = get_post_meta($postId, "channel_settings", true);
                $channelSetting         = isset($allChannelSetting[$button])&&is_array($allChannelSetting[$button]) ? $allChannelSetting[$button] : [];
                $channelSetting         = shortcode_atts($defaultChannelSettings, $channelSetting);
                ?>
                <li class="gsb-settings" id="social-buttons-<?php echo esc_attr($icon['label']) ?>-settings" data-button="<?php echo esc_attr($icon['label']) ?>">
                    <div class="gsb-settings-top">
                        <div class="gsb-free-settings">
                            <div class="gsb-input-icon">
                                <span class="ginger-button-icon ssb-btn-bg-<?php echo esc_attr($icon['label']) ?>"
                                      data-ginger-tooltip="<?php esc_attr_e($icon['title']) ?>">
                                    <?php echo $icon['icon'] ?>
                                </span>
                            </div>
                            <div class="gsb-input-value">
                                <div class="gp-form-field channel-input">
                                    <div class="gp-form-label">
                                        <label for="ginger_sb_<?php echo esc_attr($icon['label']) ?>_value"><?php echo esc_attr($icon['value']) ?>
                                            <?php if ($icon['label'] == "whatsapp") { ?>
                                                <a data-ginger-tooltip="Fill in your Phone number without any spaces and symbols"
                                                   href="https://faq.whatsapp.com/en/android/26000030/" target="_blank"><span
                                                            class="dashicons dashicons-editor-help"></span></a>
                                            <?php } else if ($icon['label'] == "facebook_messenger") { ?>
                                                <a data-ginger-tooltip="How to find Facebook page ID?"
                                                   href="https://www.facebook.com/help/1503421039731588"
                                                   target="_blank"><span class="dashicons dashicons-editor-help"></span></a>
                                            <?php } else if ($icon['label'] == "line") { ?>
                                                <a data-ginger-tooltip="How to find your link?"
                                                   href="https://developers.line.biz/en/docs/messaging-api/sharing-bot/#add-an-add-friend-button-or-link-to-your-app-or-website"
                                                   target="_blank"><span class="dashicons dashicons-editor-help"></span></a>
                                            <?php } else if ($icon['label'] == "signal") { ?>
                                                <a data-ginger-tooltip="How to get Group Id?"
                                                   href="https://support.signal.org/hc/en-us/articles/360051086971-Group-Link-or-QR-code"
                                                   target="_blank"><span class="dashicons dashicons-editor-help"></span></a>
                                            <?php } ?>
                                        </label>
                                    </div>
                                    <div class="gp-form-input">
                                        <input placeholder="<?php echo esc_attr($icon['example']) ?>"
                                               data-label="<?php echo esc_attr($icon['value']) ?>"
                                               class="setting-input <?php echo esc_attr($icon['class_name']) ?>"
                                               type="text" id="ginger_sb_<?php echo esc_attr($icon['label']) ?>_value"
                                               name="channel_settings[<?php echo esc_attr($button) ?>][value]"
                                               value="<?php echo esc_attr($channelSetting['value']); ?>">
                                    </div>
                                </div>
                            </div>
                            <div class="gsb-title">
                                <div class="gp-form-field channel-input">
                                    <div class="gp-form-label">
                                        <label for="ginger_sb_<?php echo esc_attr($icon['label']) ?>_title"><?php esc_html_e("Title", "sticky-chat-widget") ?></label>
                                    </div>
                                    <div class="gp-form-input">
                                        <input data-label="<?php esc_html_e('Title', 'sticky-chat-widget') ?>" data-channel="<?php echo esc_attr($icon['label']) ?>"
                                               class="setting-input channel-title is-required"
                                               type="text" id="ginger_sb_<?php echo esc_attr($icon['label']) ?>_title"
                                               name="channel_settings[<?php echo esc_attr($button) ?>][title]"
                                               value="<?php echo esc_attr($channelSetting['title']) ?>">
                                    </div>
                                </div>
                            </div>
                            <div class="load-more-setting">
                                <a class="load-channel-settings" href="javascript:;" data-ginger-tooltip="Settings">
                                    <?php echo $formIcons['setting'] ?>
                                    <span class="setting-label"><?php esc_html_e("Settings", "sticky-chat-widget"); ?></span>
                                </a>
                            </div>
                            <div class="gsb-more-settings">
                                <a class="remove-channel-setting" href="javascript:;" data-ginger-tooltip="Remove">
                                    <?php echo $formIcons['close'] ?>
                                </a>
                            </div>
                        </div>
                        <div class="pro-settings">
                            <div class="pro-content-to-show">
                                <div class="input-settings device-img-option">
                                    <div class="input-setting for-mobile-desktop device-option-responsive">
                                        <span class="dashboard-switch in-flex on-off">
                                            <input type="hidden" name="channel_settings[<?php echo esc_attr($button) ?>][for_desktop]" value="no">
                                            <input type="checkbox" id="ginger_sb_<?php echo esc_attr($icon['label']) ?>_for_desktop"
                                                   name="channel_settings[<?php echo esc_attr($button) ?>][for_desktop]" value="yes"
                                                   class="sr-only btn-for-desktop" <?php checked($channelSetting['for_desktop'], "yes") ?>>
                                            <label for="ginger_sb_<?php echo esc_attr($icon['label']) ?>_for_desktop"><?php esc_html_e("Desktop", "sticky-chat-widget") ?></label>
                                        </span>
                                        <span class="dashboard-switch in-flex on-off">
                                            <input type="hidden" name="channel_settings[<?php echo esc_attr($button) ?>][for_mobile]" value="no">
                                            <input type="checkbox" id="ginger_sb_<?php echo esc_attr($icon['label']) ?>_for_mobile"
                                                   name="channel_settings[<?php echo esc_attr($button) ?>][for_mobile]" value="yes"
                                                   class="sr-only btn-for-mobile" <?php checked($channelSetting['for_mobile'], "yes") ?>>
                                            <label for="ginger_sb_<?php echo esc_attr($icon['label']) ?>_for_mobile"><?php esc_html_e("Mobile", "sticky-chat-widget") ?></label>
                                        </span>
                                    </div>
                                    <div class="input-setting gp-form-field in-flex custom-img">
                                        <div class="gp-form-label channel-custom-img" style="flex: 0 0 110px;">
                                            <?php esc_html_e("Custom image", "sticky-chat-widget") ?>
                                        </div>
                                        <div class="gp-form-input upgrade-upload-btn">
                                            <a
                                                <?php if (!empty($disabled)) { ?>
                                                    data-ginger-tooltip="<?php esc_html_e("Upgrade to Pro", 'sticky-chat-widget') ?>" target="_blank" href="javascript:;"
                                                <?php } else { ?>
                                                    href="javascript:;"
                                                <?php } ?>
                                                    class="image-upload-btn img-upgrade-btn <?php echo esc_attr($disabled) ?>"><?php echo $formIcons['upload'] ?><span><?php esc_html_e(" Upload", "sticky-chat-widget") ?></span></a>
                                        </div>
                                    </div>
                                </div>
                                <div class="gp-form-field in-flex">
                                    <div class="gp-form-label"><label for="whatsapp_message"><?php esc_html_e("Background Color", "sticky-chat-widget") ?></label>
                                    </div>
                                    <div class="gp-form-input color-section">
                                        <div class="color-choice">
                                            <ul>
                                                <li class="margin-right"><?php esc_html_e("Default", "sticky-chat-widget") ?></li>
                                                <li>
                                                    <input type="text"
                                                           name="channel_settings[<?php echo esc_attr($button) ?>][bg_color]"
                                                           class="color-picker channel-bg-color"
                                                           style="background: <?php echo esc_attr($channelSetting['bg_color']) ?>"
                                                           value="<?php echo esc_attr($channelSetting['bg_color']) ?>">
                                                </li>
                                                <li><?php esc_html_e("On Hover", "sticky-chat-widget") ?></li>
                                                <li>
                                                    <input type="text"
                                                           name="channel_settings[<?php echo esc_attr($button) ?>][bg_hover_color]"
                                                           class="color-picker channel-bg-hover-color"
                                                           style="background: <?php echo esc_attr($channelSetting['bg_hover_color']) ?>"
                                                           value="<?php echo esc_attr($channelSetting['bg_hover_color']) ?>">
                                                </li>
                                            </ul>
                                        </div>
                                    </div>
                                </div>
                                <div class="gp-form-field in-flex">
                                    <div class="gp-form-label"><label for="whatsapp_message"><?php esc_html_e("Icon Color", "sticky-chat-widget") ?></label></div>
                                    <div class="gp-form-input color-section">
                                        <div class="color-choice">
                                            <ul>
                                                <li class="margin-right"><?php esc_html_e("Default", "sticky-chat-widget") ?></li>
                                                <li>
                                                    <input type="text"
                                                           name="channel_settings[<?php echo esc_attr($button) ?>][text_color]"
                                                           class="color-picker channel-text-color"
                                                           style="background: <?php echo esc_attr($channelSetting['text_color']) ?>"
                                                           value="<?php echo esc_attr($channelSetting['text_color']) ?>">
                                                </li>
                                                <li><?php esc_html_e("On Hover", "sticky-chat-widget") ?></li>
                                                <li>
                                                    <input type="text"
                                                           name="channel_settings[<?php echo esc_attr($button) ?>][text_hover_color]"
                                                           class="color-picker channel-text-hover-color"
                                                           style="background: <?php echo esc_attr($channelSetting['text_hover_color']) ?>"
                                                           value="<?php echo esc_attr($channelSetting['text_hover_color']) ?>">
                                                </li>
                                            </ul>
                                        </div>
                                    </div>
                                </div>
                                <?php if ($icon['label'] == "whatsapp") {
                                    $whatsappMessage = isset($channelSetting['whatsapp_message']) ? $channelSetting['whatsapp_message'] : ""; ?>
                                    <div class="gp-form-field in-flex">
                                        <div class="gp-form-label"><label for="whatsapp_message"><?php esc_html_e("Pre defined message", "sticky-chat-widget") ?></label></div>
                                        <div class="gp-form-input">
                                            <input type="text" id="whatsapp_message" value="<?php echo esc_attr($whatsappMessage) ?>" class="medium-input"
                                                   name="channel_settings[<?php echo esc_attr($button) ?>][whatsapp_message]">
                                        </div>
                                    </div>
                                <?php } else if ($icon['label'] == "mail") {
                                    $emailSubject = isset($channelSetting['email_subject']) ? $channelSetting['email_subject'] : ""; ?>
                                    <div class="gp-form-field in-flex">
                                        <div class="gp-form-label"><label for="email_subject"><?php esc_html_e("Email subject", "sticky-chat-widget") ?></label></div>
                                        <div class="gp-form-input">
                                            <input type="text" id="email_subject" value="<?php echo esc_attr($emailSubject) ?>"
                                                   name="channel_settings[<?php echo esc_attr($button) ?>][email_subject]">
                                        </div>
                                    </div>
                                <?php } ?>
                                <div class="gp-form-field in-flex">
                                    <div class="gp-form-label"><label for="custom_id_<?php echo esc_attr($icon['label']) ?>"><?php esc_html_e("Custom ID", "sticky-chat-widget") ?></label></div>
                                    <div class="gp-form-input">
                                        <input <?php echo esc_attr($disabled) ?> id="custom_id_<?php echo esc_attr($icon['label']) ?>" type="text"
                                         name="channel_settings[<?php echo esc_attr($button) ?>][custom_id]" value="<?php echo esc_attr($channelSetting['custom_id']) ?>">
                                        <?php if (!empty($disabled)) { ?>
                                            <a class="upgrade-link"
                                               href="javascript:;"
                                               target="_blank"><?php esc_html_e('Pro', 'sticky-chat-widget') ?></a>
                                        <?php } ?>
                                    </div>
                                </div>
                                <div class="gp-form-field in-flex">
                                    <div class="gp-form-label"><label for="custom_class_<?php echo esc_attr($button) ?>"><?php esc_html_e("Custom Class", "sticky-chat-widget") ?></label>
                                    </div>
                                    <div class="gp-form-input">
                                        <input <?php echo esc_attr($disabled) ?> id="custom_class_<?php echo esc_attr($icon['label']) ?>" type="text"
                                         name="channel_settings[<?php echo esc_attr($button) ?>][custom_class]" value="<?php echo esc_attr($channelSetting['custom_class']) ?>">
                                        <?php if (!empty($disabled)) { ?>
                                            <a class="upgrade-link"
                                               href="javascript:;"
                                               target="_blank"><?php esc_html_e('Pro', 'sticky-chat-widget') ?></a>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </li>
                <?php
                $message = ob_get_clean();
            }//end if
        }//end foreach

        return $message;

    }//end get_channel_settings()


    /**
     * Register a post type.
     *
     * @since  1.1.2
     * @return null.
     */
    public function register_post_type()
    {
        register_post_type(
            'gsb_buttons',
            // CPT Options.
             [
                 'labels'       => [
                     'name'          => __('Sticky Widgets', 'sticky-chat-widget'),
                     'singular_name' => __('Sticky Widgets', 'sticky-chat-widget'),
                 ],
                 'public'       => false,
                 'has_archive'  => false,
                 'rewrite'      => ['slug' => 'gsb_buttons'],
                 'show_in_rest' => false,
             ]
        );

    }//end register_post_type()


    /**
     * Migrate option value to meta value.
     *
     * @since  1.1.2
     * @return null.
     */
    public function migrate_data()
    {
        $flag = get_option("is_scw_database_migrated");
        if ($flag === false) {
            add_option("is_scw_database_migrated", 1);

            $widgetStatus = get_option("gsb_widget_active");
            if ($widgetStatus === false) {
                return;
            }

            $selectedChannels = get_option("gsb_selected_channels");

            if (!empty($selectedChannels)) {
                $selectedChannels = trim($selectedChannels);
                $selectedChannels = trim($selectedChannels, ",");
                $selectedChannels = explode(",", $selectedChannels);

                $channels = [];
                foreach ($selectedChannels as $channel) {
                    $channels[$channel] = get_option("ginger_sb_".$channel);
                }

                $widgetSettings = get_option("gsb_widget_settings");

                $triggerRuleSettings = get_option("gsb_trigger_rules");

                $pageRuleSettings = get_option("gsb_page_rules");

                $displayRuleSettings = get_option("gsb_time_rules");

                $tooltipSettings = get_option("gsb_tooltip_settings");

                $updatedDate = get_option("gsb_updated_date");

                $gglAnalyticsSettings = get_option("gsb_google_analytics");

                $buttonCss = get_option("gsb_button_css");

                $postID = 0;
                if (empty($postID)) {
                    $postData = [
                        'post_title'  => 'Settings',
                        'post_status' => 'publish',
                        'post_type'   => 'gsb_buttons',
                    ];
                    $postID   = wp_insert_post($postData);
                }

                if (!empty($postID)) {
                    add_post_meta($postID, "channel_settings", $channels);
                    add_post_meta($postID, "selected_channels", get_option("gsb_selected_channels"));
                    add_post_meta($postID, "widget_settings", $widgetSettings);
                    add_post_meta($postID, "trigger_rules", $triggerRuleSettings);
                    add_post_meta($postID, "page_rules", $pageRuleSettings);
                    add_post_meta($postID, "display_rules", $displayRuleSettings);
                    add_post_meta($postID, "tooltip_settings", $tooltipSettings);
                    add_post_meta($postID, "google_analytics", $gglAnalyticsSettings);
                    add_post_meta($postID, "widget_status", $widgetStatus);
                    add_post_meta($postID, "button_css", $buttonCss);
                    $response['status']  = 1;
                    $response['message'] = esc_html__("Settings are saved successfully", "sticky-chat-widget");
                }

                setcookie("scw-button", -1, (time() - 3600), "/");
                setcookie("scw-status", -1, (time() - 3600), "/");

                delete_option("gsb_selected_channels");

                $socialIcons = Ginger_Social_Icons::icon_list();
                foreach ($socialIcons as $icon) {
                    delete_option("ginger_sb_".$icon['label']);
                }

                delete_option("gsb_widget_settings");

                delete_option("gsb_trigger_rules");

                delete_option("gsb_page_rules");

                delete_option("gsb_time_rules");

                delete_option("gsb_tooltip_settings");

                delete_option("gsb_updated_date");

                delete_option("gsb_google_analytics");

                delete_option("gsb_widget_active");

                delete_option("gsb_button_css");

                do_action("clear_cache_for_scw_plugin");
            }//end if
        }//end if

    }//end migrate_data()


    /**
     * Enqueue style and script file.
     *
     * @since 1.1.2
     * @param string $hook The name of page in admin URL.
     */
    public function admin_script($hook)
    {
        if ($hook != 'toplevel_page_sticky-chat-widget') {
            return;
        }

        $minified = ".min";
        if (GSB_DEV_VERSION) {
            $minified = "";
        }

        wp_enqueue_script('gsb-admin-script', GSB_PLUGIN_URL."assets/admin/js/script".$minified.".js", [ 'jquery', 'wp-color-picker', 'jquery-ui-draggable', 'jquery-ui-droppable', 'jquery-ui-sortable', 'jquery-ui-slider' ], GSB_PLUGIN_VERSION);
        wp_enqueue_script('gsb-admin-ajax-script', GSB_PLUGIN_URL."assets/admin/js/jquery.ajaxsubmit.js", [], GSB_PLUGIN_VERSION);
        wp_enqueue_script('gsb-sumo-select-script', GSB_PLUGIN_URL."assets/admin/js/jquery.sumoselect.min.js", [], GSB_PLUGIN_VERSION);

        wp_enqueue_style('wp-color-picker');

        wp_enqueue_style('ssb-font-awesome', GSB_PLUGIN_URL."assets/admin/css/fontwesome.all.min.css", [], GSB_PLUGIN_VERSION);
        wp_enqueue_style('gsb-sumo-select', GSB_PLUGIN_URL."assets/admin/css/sumoselect.css", [], GSB_PLUGIN_VERSION);
        wp_enqueue_style('gsb-admin-style', GSB_PLUGIN_URL."assets/admin/css/style".$minified.".css", [], GSB_PLUGIN_VERSION);
        wp_enqueue_style('gsb-admin-custom-style', GSB_PLUGIN_URL."assets/admin/css/custom".$minified.".css", [], GSB_PLUGIN_VERSION);

        $flag = get_option($this->slug."-subscribe-hide");
        if ($flag == false) {
            wp_enqueue_style($this->slug.'-signup-style', GSB_PLUGIN_URL."assets/admin/css/sign-up".$minified.".css", [], GSB_PLUGIN_VERSION);
        }

        $socialIcons = Ginger_Social_Icons::icon_list();
        $css         = "";
        if (!empty($socialIcons)) {
            foreach ($socialIcons as $icon) {
                if ($icon['label'] != "instagram") {
                    $css .= ".social-icon.active .ssb-btn-".esc_attr($icon['label']).", .social-icon:hover .ssb-btn-".esc_attr($icon['label'])." {color: ".esc_attr($icon['color'])."; border-color: ".esc_attr($icon['color']).";}";
                    $css .= ".social-icon.active .ssb-btn-".esc_attr($icon['label'])." svg, .social-icon:hover .ssb-btn-".esc_attr($icon['label'])." svg {color: ".esc_attr($icon['color'])."; fill: ".esc_attr($icon['color']).";}";
                    $css .= ".ssb-btn-bg-".esc_attr($icon['label'])." {background-color: ".esc_attr($icon['color']).";}";
                }
            }
        }

        wp_add_inline_style('gsb-admin-style', $css);

        wp_localize_script(
            'gsb-admin-script',
            'BUTTON_SETTINGS',
            [
                'ajax_url'          => admin_url('admin-ajax.php'),
                'required_message'  => esc_html__("%s is required", "sticky-chat-widget"),
                'font_size_message' => esc_html__("Font size must be smaller than icon size", "sticky-chat-widget"),
                'nonce' => wp_create_nonce("gsb_buttons_create_widget")
            ]
        );

    }//end admin_script()


    /**
     * Get upgrade url.
     *
     * @since  1.1.2
     * @return string The URL of upgrade page.
     */
    public static function upgrade_url()
    {
        return admin_url("admin.php?page=sticky-chat-widget-upgrade-to-pro");

    }//end upgrade_url()


    /**
     * Add menu and submenu to this plugin in admin dashboard.
     *
     * @since  1.1.2
     * @return null
     */
    public function admin_menu()
    {
        add_menu_page(
            __('Sticky Chat Widget', 'sticky-chat-widget'),
            __('Sticky Chat Widget', 'sticky-chat-widget'),
            'manage_options',
            'sticky-chat-widget',
            [
                $this,
                'admin_setting_page',
            ],
            esc_url(GSB_PLUGIN_URL."assets/admin/images/scw-icon.png")
        );

        add_submenu_page(
            'sticky-chat-widget',
            esc_attr__('Dashboard', 'sticky-chat-widget'),
            esc_attr__('Dashboard', 'sticky-chat-widget'),
            'manage_options',
            'sticky-chat-widget',
            [
                $this,
                'admin_setting_page',
            ]
        );

    }//end admin_menu()


    /**
     * Include setting, help, lists and help page depending on admin URL.
     *
     * @since  1.1.2
     * @return null
     */
    public function admin_setting_page()
    {

        // Get social icon list.
        $socialIcons = Ginger_Social_Icons::icon_list();

        // Get social color list.
        $socialColors = Ginger_Social_Icons::color_list();

        // Get chat icon list.
        $closeIcons = Ginger_Social_Icons::get_chat_icons();

        // Upload icon.
        $uploadIcon = Ginger_Social_Icons::get_upload_icon();

        // Animation list.
        $animations = Ginger_Social_Icons::animation_styles();

        // Menu animation list.
        $menuAnimations = Ginger_Social_Icons::menu_animations();

        // Font list.
        $systemFonts = Ginger_Social_Icons::get_system_fonts_list();

        $googleFonts = Ginger_Social_Icons::get_google_fonts_list();

        // SVG icon.
        $formIcons = Ginger_Social_Icons::svg_icons();

        // Disabled section.
        $disabled = "disabled";

        // Upgrade Status.
        $upgrade = "has-upgrade-link";

        $postId          = 0;
        $postTitle       = "";
        $isSettingExists = 0;

        $task  = filter_input(INPUT_GET, 'task');
        $edit  = filter_input(INPUT_GET, 'edit');
        $nonce = filter_input(INPUT_GET, 'nonce');

        $flag = get_option($this->slug."-subscribe-hide");

        if ($flag == "yes") {
            if (isset($task) && $task == "edit-widget" && isset($edit) && isset($nonce)) {
                $postId = isset($edit) ? sanitize_text_field($edit) : 0;
                $nonce = isset($nonce) ? sanitize_text_field($nonce) : "";
                if (wp_verify_nonce($nonce, "edit_widget_" . $postId)) {
                    $postData = get_post($postId);
                    if (!empty($postData) && isset($postData->post_type) && $postData->post_type == "gsb_buttons") {
                        $postTitle = $postData->post_title;
                    }

                    include_once dirname(__FILE__) . "/templates/admin-settings.php";
                    include_once dirname(__FILE__) . "/templates/admin-help.php";
                }
            } else {
                $posts = get_posts(
                    [
                        "post_type"    => "gsb_buttons",
                        "num_of_posts" => 1,
                    ]
                );
                if ($this->isSettingExists()) {
                    $isSettingExists = 1;
                }

                include_once dirname(__FILE__)."/templates/admin-lists.php";
            }//end if
        } else {
            include_once dirname(__FILE__)."/templates/subscribe.php";
        }//end if

    }//end admin_setting_page()


    /**
     * Get ID of widget if widget is exists.
     *
     * @since  1.1.2
     * @return integer The ID of widget.
     */
    public function isSettingExists()
    {

        $posts  = get_posts(
            [
                "post_type"    => "gsb_buttons",
                "num_of_posts" => 1,
            ]
        );
        $postID = false;
        if (!empty($posts)) {
            $postID = isset($posts[0]->ID) ? $posts[0]->ID : false;
        }

        return $postID;

    }//end isSettingExists()


    /**
     * Save widget setting into database.
     *
     * @since  1.1.2
     * @return null
     */
    public function save_gsb_buttons_setting()
    {
        $nonce = filter_input(INPUT_POST, "nonce");
        if (isset($nonce)) {
            $nonce = sanitize_text_field($nonce);
        }

        $postId = filter_input(INPUT_POST, 'setting_id');
        if (isset($postId)) {
            $postId = sanitize_text_field($postId);
        }

        $widgetStatus = filter_input(INPUT_POST, 'widget_status', FILTER_SANITIZE_STRING);

        $response = [
            'status'  => 0,
            'message' => esc_html__("Invalid Request, Please try again", "sticky-chat-widget"),
            'data'    => [
                "URL" => admin_url("admin.php?page=sticky-chat-widget"),
            ],
        ];
        if (!empty($nonce) && wp_verify_nonce($nonce, "save_gsb_buttons_setting".$postId)) {
            $channelsSetting     = filter_input(INPUT_POST, 'channel_settings', FILTER_DEFAULT, FILTER_REQUIRE_ARRAY);
            $selectedChannel     = filter_input(INPUT_POST, 'gsb_selected_channels');
            $widgetsSetting      = filter_input(INPUT_POST, 'widget_settings', FILTER_DEFAULT, FILTER_REQUIRE_ARRAY);
            $triggerRulesSetting = filter_input(INPUT_POST, "trigger_rules", FILTER_DEFAULT, FILTER_REQUIRE_ARRAY);
            $pageRulesSetting    = filter_input(INPUT_POST, "page_rules", FILTER_DEFAULT, FILTER_REQUIRE_ARRAY);
            $displayRulesSetting = filter_input(INPUT_POST, "time_rules", FILTER_DEFAULT, FILTER_REQUIRE_ARRAY);
            $tooltipSetting      = filter_input(INPUT_POST, "tooltip_settings", FILTER_DEFAULT, FILTER_REQUIRE_ARRAY);
            $gglAnalyticsSetting = filter_input(INPUT_POST, "gsb_google_analytics");
            $buttonCssSetting    = filter_input(INPUT_POST, "gsb_button_css");
            $channelsSetting     = isset($channelsSetting) ? (array) $channelsSetting : [];
            $selectedChannel     = isset($selectedChannel) ? sanitize_text_field($selectedChannel) : "";
            $widgetsSetting      = isset($widgetsSetting) ? (array) $widgetsSetting : [];
            $triggerRulesSetting = isset($triggerRulesSetting) ? (array) $triggerRulesSetting : [];
            $pageRulesSetting    = isset($pageRulesSetting) ? (array) $pageRulesSetting : [];
            $displayRulesSetting = isset($displayRulesSetting) ? (array) $displayRulesSetting : [];
            $tooltipSetting      = isset($tooltipSetting) ? (array) $tooltipSetting : [];
            $gglAnalyticsSetting = isset($gglAnalyticsSetting) ? sanitize_text_field($gglAnalyticsSetting) : "no";
            $widgetsStatus       = isset($widgetStatus) ? sanitize_text_field($widgetStatus) : "no";
            $buttonCssSetting    = isset($buttonCssSetting) ? sanitize_text_field($buttonCssSetting) : "";

            $postData = [
                'ID' => $postId,
                'post_status' => 'publish',
                'post_type' => 'gsb_buttons',
            ];
            wp_update_post($postData);

            if (!empty($postId)) {
                update_post_meta($postId, "channel_settings", $channelsSetting);
                update_post_meta($postId, "selected_channels", $selectedChannel);
                update_post_meta($postId, "widget_settings", $widgetsSetting);
                update_post_meta($postId, "trigger_rules", $triggerRulesSetting);
                update_post_meta($postId, "page_rules", $pageRulesSetting);
                update_post_meta($postId, "display_rules", $displayRulesSetting);
                update_post_meta($postId, "tooltip_settings", $tooltipSetting);
                update_post_meta($postId, "google_analytics", $gglAnalyticsSetting);
                update_post_meta($postId, "widget_status", $widgetsStatus);
                update_post_meta($postId, "button_css", $buttonCssSetting);
                $response['status'] = 1;
                $response['message'] = esc_html__("Widget is updated successfully", "sticky-chat-widget");
            }

            setcookie("scw-button", -1, (time() - 3600), "/");
            setcookie("scw-status", -1, (time() - 3600), "/");
            setcookie("gsb-button-view-".$postId, -1, time(), "/");
            setcookie("gsb-button-click-".$postId, -1, time(), "/");

            do_action("clear_cache_for_scw_plugin");
        }//end if

        echo json_encode($response);
        exit;

    }//end save_gsb_buttons_setting()


    /**
     * Change widget status and update value in database.
     *
     * @since  1.1.2
     * @return null
     */
    public function gsb_buttons_change_status()
    {
        $nonce = filter_input(INPUT_POST, 'nonce');
        if (isset($nonce)) {
            $nonce = sanitize_text_field($_POST['nonce']);
        }

        $postId = filter_input(INPUT_POST, 'setting_id');
        if (isset($postId)) {
            $postId = sanitize_text_field($postId);
        }

        $status = filter_input(INPUT_POST, 'status');
        if (isset($status)) {
            $status = sanitize_text_field($status);
        }

        $response = [
            'status'  => 0,
            'message' => '',
            'data'    => [],
        ];
        if (!empty($nonce) && wp_verify_nonce($nonce, "gsb_buttons_action_".$postId)) {
            // $status = ($status)?"yes":"no";
            update_post_meta($postId, "widget_status", $status);
            $response['status'] = 1;
        }

        echo json_encode($response);
        exit;

    }//end gsb_buttons_change_status()


    /**
     * Remove widget from database.
     *
     * @since  1.1.2
     * @return null
     */
    public function gsb_buttons_remove_widget()
    {
        $nonce = filter_input(INPUT_POST, 'nonce');
        if (isset($nonce)) {
            $nonce = sanitize_text_field($nonce);
        }

        $postId = filter_input(INPUT_POST, 'widget_id');
        if (isset($postId)) {
            $postId = sanitize_text_field($postId);
        }

        $response = [
            'status'  => 0,
            'message' => esc_html__("Widget is removed successfully", "sticky-chat-widget"),
            'data'    => [],
        ];
        if (!empty($nonce) && wp_verify_nonce($nonce, "gsb_buttons_action_".$postId)) {
            $postId = esc_sql($postId);
            wp_delete_post($postId);
            $response['status'] = 1;
        }

        echo json_encode($response);
        exit;

    }//end gsb_buttons_remove_widget()


    /**
     * Save subscribe data.
     *
     * @since  1.1.2
     * @return null
     */
    public function scw_save_sign_up_info()
    {
        $skip = filter_input(INPUT_POST, "skip");
        if (isset($skip)) {
            $skip = sanitize_text_field($skip);
        }

        $emailId = filter_input(INPUT_POST, "email_id");
        if (isset($emailId)) {
            $emailId = sanitize_text_field($emailId);
        }

        $isSignUp = filter_input(INPUT_POST, "is_signup");
        if (isset($emailId)) {
            $isSignUp = sanitize_text_field($isSignUp);
        }

        $nonce = filter_input(INPUT_POST, "nonce");
        if (isset($nonce)) {
            $nonce = sanitize_text_field($nonce);
        }

        $response = [
            'status'  => 0,
            'message' => esc_html__("Invalid Request, Please try again", "gp-sticky-buttons"),
            'data'    => [ "URL" => admin_url("admin.php?page=sticky-chat-widget") ],
        ];
        if (!empty($nonce) && wp_verify_nonce($nonce, "scw_save_sign_up_info_nonce")) {
            if (!empty($skip)) {
                add_option($this->slug."-subscribe-hide", "yes");
                $response['status'] = 1;
            } else {
                $url          = "https://www.gingerplugins.com/subscribe-api/subscribe.php";
                $args         = [];
                $args['body'] = [
                    'email_id'  => $emailId,
                    'wp_plugin' => "scw",
                ];
                $url         .= "?email_id=".$emailId."&wp_plugin=scw";
                wp_remote_post($url, $args);
                add_option($this->slug."-subscribe-hide", "yes");
            }
        }

        echo json_encode($response);
        exit;

    }//end scw_save_sign_up_info()

    public function gsb_buttons_create_widget()
    {
        $response = [
            'status' => 0,
            'message' => esc_html__('Invalid request, Please try again', "sticky-chat-widget"),
            'data' => [
                'URL' => ''
            ]
        ];

        $widgetTitle = filter_input(INPUT_POST, 'widget_title', FILTER_SANITIZE_STRING);
        $nonce = filter_input(INPUT_POST, 'nonce', FILTER_SANITIZE_STRING);

        if (!empty($nonce) && wp_verify_nonce($nonce, "gsb_buttons_create_widget")) {
            $arg = [
                'post_title' => $widgetTitle,
                'post_type' => 'gsb_buttons',
                'post_status' => 'publish'
            ];
            $postId = wp_insert_post($arg);

            $response['status'] = 1;
            $response['message'] = "Widget is created successfully";
            $response['data']['URL'] = admin_url('admin.php?page=sticky-chat-widget&task=edit-widget&edit=' . $postId . '&nonce=' . wp_create_nonce('edit_widget_' . $postId));
        }

        echo json_encode($response);
        exit;
    }

    public function gsb_buttons_rename_widget()
    {
        $response = [
            'status' => 0,
            'message' => esc_html__('Invalid request, Please try again', "sticky-chat-widget"),
            'data' => [
                'URL' => ''
            ]
        ];

        $widgetTitle = filter_input(INPUT_POST, 'widget_title', FILTER_SANITIZE_STRING);
        $nonce = filter_input(INPUT_POST, 'nonce', FILTER_SANITIZE_STRING);
        $postId = filter_input(INPUT_POST, 'widget_id', FILTER_SANITIZE_STRING);

        if (!empty($nonce) && wp_verify_nonce($nonce, "gsb_buttons_action_" . $postId)) {
            if (!empty($postId)) {
                $arg = [
                    'ID' => $postId,
                    'post_title' => $widgetTitle,
                    'post_type' => 'gsb_buttons',
                    'post_status' => 'publish'
                ];
                wp_update_post($arg);

                $response['status'] = 1;
                $response['message'] = "Widget title is updated successfully";
            }
        }

        echo json_encode($response);
        exit;
    }


}//end class


if (class_exists("GP_Admin_Sticky_Chat_Buttons")) {
    $GP_admin_sticky_chat_buttons = new GP_Admin_Sticky_Chat_Buttons();
}