<?php
/**
 * Customize widget setting functionality of the plugin.
 *
 * @author  : Ginger Plugins <gingerplugins@gmail.com>
 * @license : GPL2
 * */
defined('ABSPATH') or die('Direct Access is not allowed');
?>

<?php
$defaultWidgetSettings = [
    'chat_icon'                     => "chat-line",
    'bg_color'                      => '#1c5fc6',
    'interaction_bg_color'          => '#1c5fc6',
    'text_color'                    => '#ffffff',
    'interaction_text_color'        => '#ffffff',
    'icon_size'                     => "56",
    'border_radius'                 => "28",
    'call_to_action'                => 'Contact Us',
    'font_family'                   => '',
    'menu_animation'                => 'ginger-menu-slide',
    'animation'                     => 'ginger-btn-shockwave',
    'position'                      => 'right',
    'menu_view'                     => 'vertical',
    'default_state'                 => 'click',
    'show_close_button'             => 'yes',
    'hide_menu_after_close_click'   => 'yes',
];
$widgetSettings        = get_post_meta($postId, "widget_settings", true);
$widgetSettings        = shortcode_atts($defaultWidgetSettings, $widgetSettings);
$imageUrl = "";
if (!empty($widgetSettings['custom_icon'])) {
    $imageData = wp_get_attachment_image_src($widgetSettings['custom_icon'], "full");
    if (!empty($imageData) && isset($imageData[0])) {
        $imageUrl = $imageData[0];
    } else {
        $customIcon = "";
    }
}
?>

<div id="icon-settings" class="setting-tab">
    <div class="setting-title"><?php esc_html_e("Widget Design", "sticky-chat-widget") ?></div>
    <div class="gp-form-field">
        <div class="gp-form-label">
            <label><?php esc_html_e("Icon:", "sticky-chat-widget") ?></label>
        </div>
        <div class="gp-form-input">
            <div class="ginger-close-icons">
                <ul>
                    <?php foreach($closeIcons as $key => $value) { ?>
                        <li class="<?php echo esc_attr($upgrade) ?>">
                            <input class="sr-only" type="radio" name="widget_settings[chat_icon]" <?php echo (!empty($disabled)) ? esc_attr($value['disabled']) : ""; ?> value="<?php echo esc_attr($key) ?>" <?php checked($widgetSettings['chat_icon'], $key) ?> id="chat_icon_<?php echo esc_attr($key) ?>">
                            <?php if ($value['disabled'] == "disabled" && !empty($disabled)) { ?>
                                <label data-ginger-tooltip="<?php esc_html_e("Upgrade to Pro", 'sticky-chat-widget') ?>" id="label-chat_icon_<?php echo esc_attr($key) ?><?php echo esc_attr($disabled) ?>" for="chat_icon_<?php echo esc_attr($key) ?>">
                                    <a class="" href="<?php echo esc_url(GP_Admin_Sticky_Chat_Buttons::upgrade_url()) ?>" target="_blank">
                                    <span class="svg-icon">
                                        <?php echo $value['icon'] ?>
                                    </span>
                                    </a>
                                </label>
                            <?php } else { ?>
                                <label id="label-chat_icon_<?php echo esc_attr($key) ?><?php echo esc_attr($disabled) ?>" for="chat_icon_<?php echo esc_attr($key) ?>">
                                <span class="svg-icon">
                                    <?php echo $value['icon'] ?>
                                </span>
                                </label>
                            <?php } ?>
                        </li>
                    <?php } ?>
                </ul>
            </div>
        </div>
    </div>
    <div class="gp-form-field">
        <div class="gp-form-label">
            <label><?php esc_html_e("Position:", "sticky-chat-widget") ?></label>
        </div>
        <div class="gp-form-input medium-input">
            <div class="gp-radio-buttons in-flex">
                <div class="gp-radio-button">
                    <input id="position_left" type="radio" class="sr-only" name="widget_settings[position]" value="left" <?php checked($widgetSettings['position'], "left") ?>>
                    <label for="position_left"><?php esc_html_e("Left", "sticky-chat-widget") ?></label>
                </div>
                <div class="gp-radio-button">
                    <input id="position_right" type="radio" class="sr-only" name="widget_settings[position]" value="right" <?php checked($widgetSettings['position'], "right") ?>>
                    <label for="position_right"><?php esc_html_e("Right", "sticky-chat-widget") ?></label>
                </div>
                <div class="gp-radio-button <?php echo esc_attr($disabled) ?> <?php echo esc_attr($upgrade) ?>">
                    <input id="position_custom" type="radio" class="sr-only" <?php echo esc_attr($disabled) ?> name="widget_settings[position]" value="custom" <?php checked($widgetSettings['position'], "custom") ?>>
                    <label for="position_custom">
                        <?php if (!empty($disabled)) { ?>
                            <a href="javascript:;" class="upgrade-link-btn" target="_blank"><?php esc_html_e("Custom (Pro)", "sticky-chat-widget") ?></a>
                        <?php } else { ?>
                            <?php esc_html_e("Custom", "sticky-chat-widget") ?>
                        <?php } ?>
                    </label>
                </div>
            </div>
        </div>
    </div>
    <div class="gp-form-field mt-20">
        <div class="gp-form-label">
            <label><?php esc_html_e("Icons view: ", "sticky-chat-widget") ?><span class="ginger-info" data-ginger-tooltip="<?php esc_html_e("You can display chat buttons menu by vertical or horizontal", 'sticky-chat-widget') ?>"><span class="dashicons dashicons-editor-help"></span></span></label>
        </div>
        <div class="gp-form-input medium-input">
            <div class="gp-radio-buttons in-flex">
                <div class="gp-radio-button">
                    <input id="menu_view_vertical" type="radio" class="sr-only" name="widget_settings[menu_view]" value="vertical" <?php checked($widgetSettings['menu_view'], "vertical") ?>>
                    <label for="menu_view_vertical"><?php esc_html_e("Vertical", "sticky-chat-widget") ?></label>
                </div>
                <div class="gp-radio-button">
                    <input id="menu_view_horizontal" type="radio" class="sr-only" name="widget_settings[menu_view]" value="horizontal" <?php checked($widgetSettings['menu_view'], "horizontal") ?>>
                    <label for="menu_view_horizontal"><?php esc_html_e("Horizontal", "sticky-chat-widget") ?></label>
                </div>
            </div>
        </div>
    </div>
    <div class="gp-form-field">
        <div class="gp-form-label">
            <label><?php esc_html_e("Default state:", "sticky-chat-widget") ?></label>
        </div>
        <div class="gp-form-input medium-input">
            <div class="gp-radio-buttons in-flex">
                <div class="gp-radio-button">
                    <input id="default_state_default" type="radio" class="sr-only default-state-option" name="widget_settings[default_state]" value="click" <?php checked($widgetSettings['default_state'], "click") ?>>
                    <label for="default_state_default"><?php esc_html_e("Click to open ", "sticky-chat-widget") ?></label>
                </div>
                <div class="gp-radio-button">
                    <input id="default_state_click" type="radio" class="sr-only default-state-option" name="widget_settings[default_state]" value="open" <?php checked($widgetSettings['default_state'], "open") ?>>
                    <label for="default_state_click"><?php esc_html_e("Open by default ", "sticky-chat-widget") ?><span class="ginger-info" data-ginger-tooltip="<?php esc_html_e("Chat buttons menu will be opened by default when website visitor will visit your website", 'sticky-chat-widget') ?>"><span class="dashicons dashicons-editor-help"></span></span></label>
                </div>
            </div>
        </div>
    </div>
    <div class="default-state <?php echo (esc_attr($widgetSettings['default_state'] == "open")) ? "active" : "" ?>">
        <span class="dashboard-switch in-flex on-off">
            <input type="hidden" name="widget_settings[show_close_button]" value="no">
            <input type="checkbox" id="show_close_button" name="widget_settings[show_close_button]" value="yes" class="sr-only" <?php checked($widgetSettings['show_close_button'], "yes") ?>>
            <label for="show_close_button"><?php esc_html_e("Show close button ", "sticky-chat-widget") ?></label><span class="ginger-info" data-ginger-tooltip="<?php esc_html_e("You can show/hide Widget close button when Default state is opened by default", 'sticky-chat-widget') ?>"><span class="dashicons dashicons-editor-help"></span></span>
        </span>
        <span class="dashboard-switch in-flex on-off <?php echo (esc_attr($widgetSettings['show_close_button'] == "yes")) ? "active" : "" ?> hide-menu-close-click">
            <input type="hidden" name="widget_settings[hide_menu_after_close_click]" value="no">
            <input type="checkbox" id="hide_menu_after_close_click" name="widget_settings[hide_menu_after_close_click]" value="yes" class="sr-only" <?php checked($widgetSettings['hide_menu_after_close_click'], "yes") ?>>
            <label for="hide_menu_after_close_click"><?php esc_html_e("Hide menu on Close button click ", "sticky-chat-widget") ?></label><span class="ginger-info" data-ginger-tooltip="<?php esc_html_e("Menu will be not opened by default once website visitor will click on widget close button", 'sticky-chat-widget') ?>"><span class="dashicons dashicons-editor-help"></span></span>
        </span>
    </div>
    <div class="gp-form-field mt-20">
        <div class="gp-form-label">
            <label for="call_to_action"><?php esc_html_e("Call to Action:", "sticky-chat-widget") ?></label>
        </div>
        <div class="gp-form-input medium-input">
            <input type="text" name="widget_settings[call_to_action]" id="ginger_sb_call_to_action" value="<?php echo esc_attr($widgetSettings['call_to_action']) ?>">
        </div>
    </div>
    <div class="gp-form-field">
        <div class="gp-form-label">
            <label for="ginger_menu_animation"><?php esc_html_e("Menu animation: ", "sticky-chat-widget") ?><span class="ginger-info" data-ginger-tooltip="<?php esc_html_e("Display social chat button menu using different animations. for preview click on widget button in preview section", 'sticky-chat-widget') ?>"><span class="dashicons dashicons-editor-help"></span></span></label>
        </div>
        <div class="gp-form-input medium-input">
            <select name="widget_settings[menu_animation]" id="ginger_menu_animation" class="sumoselect">
                <?php foreach ($menuAnimations as $key => $value) { ?>
                    <option <?php selected($value['class_name'], $widgetSettings['menu_animation']) ?> value="<?php echo esc_attr($value['class_name']) ?>"><?php echo esc_attr($value['title']) ?></option>
                <?php } ?>
            </select>
        </div>
    </div>
    <div class="gp-form-field">
        <div class="gp-form-label">
            <label><?php esc_html_e("Attention effect: ", "sticky-chat-widget") ?><span class="ginger-info" data-ginger-tooltip="<?php esc_html_e("Use different kind of attention effects for widget button", 'sticky-chat-widget') ?>"><span class="dashicons dashicons-editor-help"></span></span></label>
        </div>
        <div class="gp-form-input medium-input">
            <select name="widget_settings[animation]" id="ginger_sb_animation" class="sumoselect">
                <?php foreach ($animations as $key => $value) { ?>
                    <option <?php selected($value['class_name'], $widgetSettings['animation']) ?> value="<?php echo esc_attr($value['class_name']) ?>"><?php echo esc_attr($value['title']) ?></option>
                <?php } ?>
            </select>
        </div>
    </div>
    <div class="gp-form-field mt-20">
        <div class="gp-form-label">
            <label for="widget_icon_size"><?php esc_html_e("Icon size:", "sticky-chat-widget") ?></label>
        </div>
        <div class="gp-form-input add-prefix-text medium-input" data-prefix="PX">
            <input data-label="<?php esc_html_e('Icon size', 'sticky-chat-widget') ?>" type="text" name="widget_settings[icon_size]" id="widget_icon_size" class="only-numeric is-required" value="<?php echo esc_attr($widgetSettings['icon_size']) ?>">
        </div>
    </div>
    <div class="gp-form-field">
        <div class="gp-form-label">
            <label for="border_radius"><?php esc_html_e("Border radius:", "sticky-chat-widget") ?></label>
        </div>
        <div class="gp-form-input add-prefix-text medium-input" data-prefix="PX">
            <input type="text" name="widget_settings[border_radius]" id="border_radius" class="only-numeric" value="<?php echo esc_attr($widgetSettings['border_radius']) ?>">
        </div>
    </div>
    <div class="flex-input mt-20">
        <div class="gp-form-field in-flex">
            <div class="gp-form-label">
                <label for="icon-bg-color-custom"><?php esc_html_e("Background Color:", "sticky-chat-widget") ?></label>
            </div>
            <div class="gp-form-input ginger-color-list">
                <input id="icon-bg-color-custom" class="custom-color-picker" type="text" name="widget_settings[bg_color]" value="<?php echo esc_attr($widgetSettings['bg_color']) ?>" style="background: <?php echo esc_attr($widgetSettings['bg_color']) ?>">
            </div>
        </div>
        <div class="gp-form-field in-flex">
            <div class="gp-form-label">
                <label for="icon-bg-color-interaction-custom"><?php esc_html_e("Background Hover Color:", "sticky-chat-widget") ?></label>
            </div>
            <div class="gp-form-input ginger-color-list">
                <input id="icon-bg-color-interaction-custom" class="custom-color-picker" type="text" name="widget_settings[interaction_bg_color]" value="<?php echo esc_attr($widgetSettings['interaction_bg_color']) ?>" style="background: <?php echo esc_attr($widgetSettings['interaction_bg_color']) ?>">
            </div>
        </div>
    </div>
    <div class="flex-input mt-20">
        <div class="gp-form-field in-flex">
            <div class="gp-form-label">
                <label for="icon-text-color-custom"><?php esc_html_e("Icon Color:", "sticky-chat-widget") ?></label>
            </div>
            <div class="gp-form-input ginger-color-list">
                <input id="icon-text-color-custom" class="custom-color-picker" type="text" name="widget_settings[text_color]" value="<?php echo esc_attr($widgetSettings['text_color']) ?>" style="background: <?php echo esc_attr($widgetSettings['text_color']) ?>">
            </div>
        </div>
        <div class="gp-form-field in-flex">
            <div class="gp-form-label">
                <label for="icon-text-color-interaction-custom"><?php esc_html_e("Icon Hover Color:", "sticky-chat-widget") ?></label>
            </div>
            <div class="gp-form-input ginger-color-list">
                <input id="icon-text-color-interaction-custom" class="custom-color-picker" type="text" name="widget_settings[interaction_text_color]" value="<?php echo esc_attr($widgetSettings['interaction_text_color']) ?>" style="background: <?php echo esc_attr($widgetSettings['interaction_text_color']) ?>">
            </div>
        </div>
    </div>
    <div class="gp-form-field mt-20">
        <div class="gp-form-label">
            <label for="ginger_sb_font_family"><?php esc_html_e("Font family:", "sticky-chat-widget") ?></label>
        </div>
        <div class="gp-form-input medium-input">
            <select name="widget_settings[font_family]" id="ginger_sb_font_family" class="sumoselect-font-family">
                <option value=""><?php esc_html_e("Default", "sticky-chat-widget") ?></option>
                <optgroup label="System Font Family">
                    <?php foreach ($systemFonts as $key => $value) { ?>
                        <option <?php selected($widgetSettings['font_family'], $key) ?> value="<?php echo esc_attr($key) ?>"><?php echo esc_attr($key) ?></option>
                    <?php } ?>
                </optgroup>
                <optgroup label="Google Font Family">
                    <?php foreach ($googleFonts as $key => $value) { ?>
                        <option <?php selected($widgetSettings['font_family'], $key) ?> value="<?php echo esc_attr($key) ?>"><?php echo esc_attr($key) ?></option>
                    <?php } ?>
                </optgroup>
            </select>
        </div>
    </div>


    <?php
    require_once dirname(__FILE__) . "/analytics-settings.php";
    require_once dirname(__FILE__) . "/pending-messages.php";
    require_once dirname(__FILE__) . "/tooltip-settings.php";
    require_once dirname(__FILE__) . "/custom-css.php";
    ?>

</div>
